Unifont Utils
=============

This project provides a set of tools for working with the GNU Unifont.

See the documentation at `Read the Docs <https://unifont-utils.readthedocs.io/>`_
for more information.

Installation
------------

Install the package from PyPI using the following command:

.. code-block:: shell

    pip install unifont_utils

License
-------

::

        Unifont Utils
        Copyright (C) 2024-2025 SkyEye_FAST

        This program is free software: you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation, either version 3 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program.  If not, see <https://www.gnu.org/licenses/>.

Feedback
--------

This project is still in its early stages of development. See the
`GitHub repository <https://github.com/SkyEye-FAST/unifont_utils>`_ for
more information.

Please feel free to raise issues for any problems encountered or
feature suggestions.

Pull requests are welcome.
